<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>SnapDistance</name>
    <message>
        <location filename="../SnapDistance.ui" line="+17"/>
        <source>Snap distance:</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odległość przyciągania:</translation>
    </message>
    <message>
        <location filename="../SnapDistanceInit.js" line="+2"/>
        <source>&amp;Distance</source>
        <translatorcomment>--google--
&amp;Odległość punkt - punkt
&amp;Odległość obiektu do punktu
Odstęp od punktów &amp;końcowych</translatorcomment>
        <translation>&amp;Odległość</translation>
    </message>
</context>
</TS>
